@@ -2,7 +2,9 @@
 import asyncio
 
 from .api import GetState
+from .api.status_request import StatusRequest
 from .exception import PyVLXException
+from .opening_device import Blind
 
 
 class Heartbeat:
@@ -24,6 +26,8 @@ class Heartbeat:
 
     def start(self):
         """Create loop task."""
+        self.stopped = False
+        self.stopped_event.clear()
         self.run_task = self.pyvlx.loop.create_task(self.loop())
 
     async def stop(self):
@@ -42,7 +46,10 @@ class Heartbeat:
             await self.loop_event.wait()
             if not self.stopped:
                 self.loop_event.clear()
-                await self.pulse()
+                try:
+                    await self.pulse()
+                except PyVLXException:
+                    pass
         self.cancel_loop_timeout()
         self.stopped_event.set()
 
@@ -62,3 +69,10 @@ class Heartbeat:
         await get_state.do_api_call()
         if not get_state.success:
             raise PyVLXException("Unable to send get state.")
+
+        # If nodes contain Blind device, refresh orientation because House Monitoring
+        # delivers wrong values for FP3 parameter
+        for node in self.pyvlx.nodes:
+            if isinstance(node, Blind):
+                status_request = StatusRequest(self.pyvlx, node.node_id)
+                await status_request.do_api_call()
