@@ -7,16 +7,16 @@ and roller shutters.
 """
 import asyncio
 
-
-from .api import house_status_monitor_enable
+from .api import (
+    get_limitation, house_status_monitor_disable, house_status_monitor_enable)
 from .config import Config
 from .connection import Connection
 from .heartbeat import Heartbeat
+from .klf200gateway import Klf200Gateway
 from .log import PYVLXLOG
 from .node_updater import NodeUpdater
 from .nodes import Nodes
 from .scenes import Scenes
-from .klf200gateway import Klf200Gateway
 
 
 class PyVLX:
@@ -68,6 +68,8 @@ class PyVLX:
 
     async def disconnect(self):
         """Disconnect from KLF 200."""
+        # If the connection will be closed while house status monitor is enabled, a reconnection will fail on SSL handshake.
+        await house_status_monitor_disable(pyvlx=self)
         await self.heartbeat.stop()
         self.connection.disconnect()
 
@@ -78,3 +80,7 @@ class PyVLX:
     async def load_scenes(self):
         """Load scenes from KLF 200."""
         await self.scenes.load()
+
+    async def get_limitation(self, node_id):
+        limit = get_limitation.GetLimitation(self, [node_id])
+        await limit.do_api_call()
